Package: rassta
Title: Raster-Based Spatial Stratification Algorithms
Version: 1.0.6
Authors@R: c(person("Bryan A.", "Fuentes", role = c("aut", "cre"),
                     email = "bryandrep@gmail.com",
                     comment = c(ORCID = "0000-0003-3506-7101")),
             person("Minerva J.", "Dorantes", role = c("aut"),
                     email = "mdorant2@gmail.com",
                     comment = c(ORCID = "0000-0002-2877-832X")),
             person("John R.", "Tipton", role = c("aut"),
                     email = "jrtipton@uark.edu"),
             person("Robert J.", "Hijmans", role = "ctb",
                     email = "r.hijmans@gmail.com",
                     comment = c(ORCID = "0000-0001-5872-2872")),
             person("Andrew G.", "Brown", role = "ctb",
                     email = "brown.andrewg@gmail.com")
            )
Description: Algorithms for the spatial stratification of landscapes, sampling and modeling of 
    spatially-varying phenomena. These algorithms offer a simple framework for the stratification 
    of geographic space based on raster layers representing landscape factors and/or factor scales. 
    The stratification process follows a hierarchical approach, which is based on first level units 
    (i.e., classification units) and second-level units (i.e., stratification units). Nonparametric 
    techniques allow to measure the correspondence between the geographic space and the landscape 
    configuration represented by the units. These correspondence metrics are useful to define 
    sampling schemes and to model the spatial variability of environmental phenomena. The 
    theoretical background of the algorithms and code examples are presented in Fuentes et al. (2022). 
    <doi:10.32614/RJ-2022-036>.
Maintainer: Bryan A. Fuentes <bryandrep@gmail.com>
License: AGPL (>= 3)
Encoding: UTF-8
URL: https://bafuentes.github.io/rassta/
BugReports: https://github.com/bafuentes/rassta/issues/
RoxygenNote: 7.3.2
Imports: cluster (>= 2.1.2), data.table (>= 1.14.0), dplyr (>= 1.0.7),
        DT (>= 0.18), foreach (>= 1.5.1), GGally (>= 2.1.2), ggplot2
        (>= 3.3.5), grDevices, histogram (>= 0.0.25), KernSmooth (>=
        2.23.18), kohonen (>= 3.0.10), plotly (>= 4.9.4.1), rlang (>=
        0.4.11), scales (>= 1.1.1), shiny (>= 1.6.0), stats, stringdist
        (>= 0.9.6.3), stringi (>= 1.7.2), terra (>= 1.3.4), utils
Suggests: testthat (>= 3.0.0), tinytest (>= 1.3.1), doParallel (>=
        1.0.16), mgcv (>= 1.8.40), knitr, rmarkdown
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-08-18 23:49:48 UTC; bryan
Author: Bryan A. Fuentes [aut, cre] (<https://orcid.org/0000-0003-3506-7101>),
  Minerva J. Dorantes [aut] (<https://orcid.org/0000-0002-2877-832X>),
  John R. Tipton [aut],
  Robert J. Hijmans [ctb] (<https://orcid.org/0000-0001-5872-2872>),
  Andrew G. Brown [ctb]
Repository: CRAN
Date/Publication: 2024-08-19 06:20:13 UTC
Built: R 4.6.0; ; 2026-04-30 15:42:21 UTC; unix
