# Generated by roxygen2: do not edit by hand

export(dummies)
export(engine)
export(figure)
export(locations)
export(observation)
export(plot3D)
export(predict_functions)
export(select_functions)
export(signature)
export(similarity)
export(som_gap)
export(som_pam)
export(strata)
